#[non_exhaustive]pub struct GaplessInfo {
pub leading_frames: u64,
pub trailing_frames: u64,
}Expand description
Gapless trim contract for one decoded track.
The values are expressed in PCM frames, not scalar samples:
leading_frames are dropped from the start of the track and
trailing_frames are dropped from the end at EOF.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.leading_frames: u64trailing_frames: u64Trait Implementations
Sourceimpl Clone for GaplessInfo
impl Clone for GaplessInfo
Sourcefn clone(&self) -> GaplessInfo
fn clone(&self) -> GaplessInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GaplessInfo
impl Debug for GaplessInfo
Sourceimpl Default for GaplessInfo
impl Default for GaplessInfo
Sourcefn default() -> GaplessInfo
fn default() -> GaplessInfo
Returns the “default value” for a type. Read more
Sourceimpl From<GaplessInfo> for GaplessTrimmer
impl From<GaplessInfo> for GaplessTrimmer
Sourcefn from(info: GaplessInfo) -> Self
fn from(info: GaplessInfo) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for GaplessInfo
impl PartialEq for GaplessInfo
Sourcefn eq(&self, other: &GaplessInfo) -> bool
fn eq(&self, other: &GaplessInfo) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for GaplessInfo
impl Eq for GaplessInfo
impl StructuralPartialEq for GaplessInfo